@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 # Some of the subclasses that get used as settings-overrides will yield this pylint
 # error, but they do get used when included as part of the override_settings
 # pylint: disable=too-few-public-methods
@@ -34,7 +33,7 @@ class MockSearchTests(TestCase, SearcherMixin):
         return isinstance(self.searcher, ElasticSearchEngine)
 
     def setUp(self):
-        super(MockSearchTests, self).setUp()
+        super().setUp()
         # ignore unexpected-keyword-arg; ES python client documents that it can be used
         # pylint: disable=unexpected-keyword-arg
         if self._is_elastic:
@@ -61,7 +60,7 @@ class MockSearchTests(TestCase, SearcherMixin):
             MockSearchEngine.destroy()
 
         self._searcher = None
-        super(MockSearchTests, self).tearDown()
+        super().tearDown()
 
     def test_factory_creator(self):
         """ Make sure that search object implements SearchEngine interface """
@@ -296,7 +295,7 @@ class MockSearchTests(TestCase, SearcherMixin):
 
     def test_extended_characters(self):
         """ Make sure that extended character searches work """
-        test_string = u"قضايـا هامـة"
+        test_string = "قضايـا هامـة"
         self.searcher.index([{"content": {"name": test_string}}])
 
         # search string
